Class: Google::Cloud::Spanner::V1::BatchCreateSessionsRequest

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/spanner/v1/spanner.rb

Overview

The request for BatchCreateSessions.

Instance Attribute Summary collapse

Instance Attribute Details

#database::String

Returns Required. The database in which the new sessions are created.

Returns:

  • (::String)

    Required. The database in which the new sessions are created.



52
53
54
55
# File 'proto_docs/google/spanner/v1/spanner.rb', line 52

class BatchCreateSessionsRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#session_count::Integer

Returns Required. The number of sessions to be created in this batch call. At least one session is created. The API can return fewer than the requested number of sessions. If a specific number of sessions are desired, the client can make additional calls to BatchCreateSessions (adjusting session_count as necessary).

Returns:

  • (::Integer)

    Required. The number of sessions to be created in this batch call. At least one session is created. The API can return fewer than the requested number of sessions. If a specific number of sessions are desired, the client can make additional calls to BatchCreateSessions (adjusting session_count as necessary).



52
53
54
55
# File 'proto_docs/google/spanner/v1/spanner.rb', line 52

class BatchCreateSessionsRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#session_template::Google::Cloud::Spanner::V1::Session

Returns Parameters to apply to each created session.

Returns:



52
53
54
55
# File 'proto_docs/google/spanner/v1/spanner.rb', line 52

class BatchCreateSessionsRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end