Class: Google::Cloud::Spanner::V1::BatchWriteResponse
- Inherits:
-
Object
- Object
- Google::Cloud::Spanner::V1::BatchWriteResponse
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/spanner/v1/spanner.rb
Overview
The result of applying a batch of mutations.
Instance Attribute Summary collapse
-
#commit_timestamp ⇒ ::Google::Protobuf::Timestamp
The commit timestamp of the transaction that applied this batch.
-
#indexes ⇒ ::Array<::Integer>
The mutation groups applied in this batch.
-
#status ⇒ ::Google::Rpc::Status
An
OKstatus indicates success.
Instance Attribute Details
#commit_timestamp ⇒ ::Google::Protobuf::Timestamp
Returns The commit timestamp of the transaction that applied this batch. Present if status is OK and the mutation groups were applied, absent otherwise.
For mutation groups with conditions, a status=OK and missing commit_timestamp means that the mutation groups were not applied due to the condition not being satisfied after evaluation.
1196 1197 1198 1199 |
# File 'proto_docs/google/spanner/v1/spanner.rb', line 1196 class BatchWriteResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#indexes ⇒ ::Array<::Integer>
Returns The mutation groups applied in this batch. The values index into the
mutation_groups field in the corresponding BatchWriteRequest.
1196 1197 1198 1199 |
# File 'proto_docs/google/spanner/v1/spanner.rb', line 1196 class BatchWriteResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#status ⇒ ::Google::Rpc::Status
Returns An OK status indicates success. Any other status indicates a failure.
1196 1197 1198 1199 |
# File 'proto_docs/google/spanner/v1/spanner.rb', line 1196 class BatchWriteResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |