Class: Google::Cloud::Spanner::V1::ChangeStreamRecord::DataChangeRecord::ColumnMetadata

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/spanner/v1/change_stream.rb

Overview

Metadata for a column.

Instance Attribute Summary collapse

Instance Attribute Details

#is_primary_key::Boolean

Returns Indicates whether the column is a primary key column.

Returns:

  • (::Boolean)

    Indicates whether the column is a primary key column.



161
162
163
164
# File 'proto_docs/google/spanner/v1/change_stream.rb', line 161

class ColumnMetadata
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#name::String

Returns Name of the column.

Returns:

  • (::String)

    Name of the column.



161
162
163
164
# File 'proto_docs/google/spanner/v1/change_stream.rb', line 161

class ColumnMetadata
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#ordinal_position::Integer

Returns Ordinal position of the column based on the original table definition in the schema starting with a value of 1.

Returns:

  • (::Integer)

    Ordinal position of the column based on the original table definition in the schema starting with a value of 1.



161
162
163
164
# File 'proto_docs/google/spanner/v1/change_stream.rb', line 161

class ColumnMetadata
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#type::Google::Cloud::Spanner::V1::Type

Returns Type of the column.

Returns:



161
162
163
164
# File 'proto_docs/google/spanner/v1/change_stream.rb', line 161

class ColumnMetadata
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end