Class: Google::Cloud::Spanner::V1::ChangeStreamRecord::HeartbeatRecord

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/spanner/v1/change_stream.rb

Overview

A heartbeat record is returned as a progress indicator, when there are no data changes or any other partition record types in the change stream partition.

Instance Attribute Summary collapse

Instance Attribute Details

#timestamp::Google::Protobuf::Timestamp

Returns Indicates the timestamp at which the query has returned all the records in the change stream partition with timestamp <= heartbeat timestamp. The heartbeat timestamp will not be the same as the timestamps of other record types in the same partition.

Returns:

  • (::Google::Protobuf::Timestamp)

    Indicates the timestamp at which the query has returned all the records in the change stream partition with timestamp <= heartbeat timestamp. The heartbeat timestamp will not be the same as the timestamps of other record types in the same partition.



253
254
255
256
# File 'proto_docs/google/spanner/v1/change_stream.rb', line 253

class HeartbeatRecord
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end