Class: Google::Cloud::Spanner::V1::ChangeStreamRecord::PartitionEventRecord::MoveOutEvent

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/spanner/v1/change_stream.rb

Overview

Describes move-out of the key ranges out of the change stream partition identified by partition_token.

To maintain processing the changes for a particular key in timestamp order, the query processing the MoveOutEvent in the partition identified by partition_token should inform the queries processing the destination partitions that they can unblock and proceed processing records past the commit_timestamp.

Instance Attribute Summary collapse

Instance Attribute Details

#destination_partition_token::String

Returns An unique partition identifier describing the destination change stream partition that will record changes for the key range that is moving out of this partition.

Returns:

  • (::String)

    An unique partition identifier describing the destination change stream partition that will record changes for the key range that is moving out of this partition.



479
480
481
482
# File 'proto_docs/google/spanner/v1/change_stream.rb', line 479

class MoveOutEvent
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end