Class: Google::Cloud::Spanner::V1::ChangeStreamRecord::PartitionStartRecord

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/spanner/v1/change_stream.rb

Overview

A partition start record serves as a notification that the client should schedule the partitions to be queried. PartitionStartRecord returns information about one or more partitions.

Instance Attribute Summary collapse

Instance Attribute Details

#partition_tokens::Array<::String>

Returns Unique partition identifiers to be used in queries.

Returns:

  • (::Array<::String>)

    Unique partition identifiers to be used in queries.



280
281
282
283
# File 'proto_docs/google/spanner/v1/change_stream.rb', line 280

class PartitionStartRecord
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#record_sequence::String

Returns Record sequence numbers are unique and monotonically increasing (but not necessarily contiguous) for a specific timestamp across record types in the same partition. To guarantee ordered processing, the reader should process records (of potentially different types) in record_sequence order for a specific timestamp in the same partition.

Returns:

  • (::String)

    Record sequence numbers are unique and monotonically increasing (but not necessarily contiguous) for a specific timestamp across record types in the same partition. To guarantee ordered processing, the reader should process records (of potentially different types) in record_sequence order for a specific timestamp in the same partition.



280
281
282
283
# File 'proto_docs/google/spanner/v1/change_stream.rb', line 280

class PartitionStartRecord
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#start_timestamp::Google::Protobuf::Timestamp

Returns Start timestamp at which the partitions should be queried to return change stream records with timestamps >= start_timestamp. DataChangeRecord.commit_timestamps, PartitionStartRecord.start_timestamps, PartitionEventRecord.commit_timestamps, and PartitionEndRecord.end_timestamps can have the same value in the same partition.

Returns:

  • (::Google::Protobuf::Timestamp)

    Start timestamp at which the partitions should be queried to return change stream records with timestamps >= start_timestamp. DataChangeRecord.commit_timestamps, PartitionStartRecord.start_timestamps, PartitionEventRecord.commit_timestamps, and PartitionEndRecord.end_timestamps can have the same value in the same partition.



280
281
282
283
# File 'proto_docs/google/spanner/v1/change_stream.rb', line 280

class PartitionStartRecord
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end