Class: Google::Cloud::Spanner::V1::Group

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/spanner/v1/location.rb

Overview

A Group represents a paxos group in a database. A group is a set of tablets that are replicated across multiple servers. Groups may have a leader tablet. Groups store one (or sometimes more) ranges of keys.

Instance Attribute Summary collapse

Instance Attribute Details

#generation::String

Returns generation indicates the freshness of the group information (including leader information) contained in this proto. Generations can be compared lexicographically; if generation A is greater than generation B, then the Group corresponding to A is newer than the Group corresponding to B, and should be used preferentially.

Returns:

  • (::String)

    generation indicates the freshness of the group information (including leader information) contained in this proto. Generations can be compared lexicographically; if generation A is greater than generation B, then the Group corresponding to A is newer than the Group corresponding to B, and should be used preferentially.



171
172
173
174
# File 'proto_docs/google/spanner/v1/location.rb', line 171

class Group
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#group_uid::Integer

Returns The UID of the paxos group, unique within the database. Matches the group_uid field in Range.

Returns:

  • (::Integer)

    The UID of the paxos group, unique within the database. Matches the group_uid field in Range.



171
172
173
174
# File 'proto_docs/google/spanner/v1/location.rb', line 171

class Group
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#leader_index::Integer

Returns The last known leader tablet of the group as an index into tablets. May be negative if the group has no known leader.

Returns:

  • (::Integer)

    The last known leader tablet of the group as an index into tablets. May be negative if the group has no known leader.



171
172
173
174
# File 'proto_docs/google/spanner/v1/location.rb', line 171

class Group
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#tablets::Array<::Google::Cloud::Spanner::V1::Tablet>

Returns A list of tablets that are part of the group. Note that this list may not be exhaustive; it will only include tablets the server considers useful to the client. The returned list is ordered ascending by distance.

Tablet UIDs reference Tablet.tablet_uid.

Returns:

  • (::Array<::Google::Cloud::Spanner::V1::Tablet>)

    A list of tablets that are part of the group. Note that this list may not be exhaustive; it will only include tablets the server considers useful to the client. The returned list is ordered ascending by distance.

    Tablet UIDs reference Tablet.tablet_uid.



171
172
173
174
# File 'proto_docs/google/spanner/v1/location.rb', line 171

class Group
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end