Class: Google::Cloud::Spanner::V1::KeyRecipe::Part

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/spanner/v1/location.rb

Overview

An ssformat key is composed of a sequence of tag numbers and key column values. Part represents a single tag or key column value.

Defined Under Namespace

Modules: NullOrder, Order

Instance Attribute Summary collapse

Instance Attribute Details

#identifier::String

Returns identifier is the name of the column or query parameter.

Note: The following fields are mutually exclusive: identifier, value, random. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:

  • (::String)

    identifier is the name of the column or query parameter.

    Note: The following fields are mutually exclusive: identifier, value, random. If a field in that set is populated, all other fields in the set will automatically be cleared.



242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
# File 'proto_docs/google/spanner/v1/location.rb', line 242

class Part
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The remaining fields encode column values.
  module Order
    # Default value, equivalent to `ASCENDING`.
    ORDER_UNSPECIFIED = 0

    # The key is ascending - corresponds to `ASC` in the schema definition.
    ASCENDING = 1

    # The key is descending - corresponds to `DESC` in the schema definition.
    DESCENDING = 2
  end

  # The null order of the key column. This dictates where NULL values sort
  # in the sorted order. Note that columns which are `NOT NULL` can have a
  # special encoding.
  module NullOrder
    # Default value. This value is unused.
    NULL_ORDER_UNSPECIFIED = 0

    # NULL values sort before any non-NULL values.
    NULLS_FIRST = 1

    # NULL values sort after any non-NULL values.
    NULLS_LAST = 2

    # The column does not support NULL values.
    NOT_NULL = 3
  end
end

#null_order::Google::Cloud::Spanner::V1::KeyRecipe::Part::NullOrder

Returns How NULLs are represented in the encoded key part. Only present if tag is zero.

Returns:



242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
# File 'proto_docs/google/spanner/v1/location.rb', line 242

class Part
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The remaining fields encode column values.
  module Order
    # Default value, equivalent to `ASCENDING`.
    ORDER_UNSPECIFIED = 0

    # The key is ascending - corresponds to `ASC` in the schema definition.
    ASCENDING = 1

    # The key is descending - corresponds to `DESC` in the schema definition.
    DESCENDING = 2
  end

  # The null order of the key column. This dictates where NULL values sort
  # in the sorted order. Note that columns which are `NOT NULL` can have a
  # special encoding.
  module NullOrder
    # Default value. This value is unused.
    NULL_ORDER_UNSPECIFIED = 0

    # NULL values sort before any non-NULL values.
    NULLS_FIRST = 1

    # NULL values sort after any non-NULL values.
    NULLS_LAST = 2

    # The column does not support NULL values.
    NOT_NULL = 3
  end
end

#order::Google::Cloud::Spanner::V1::KeyRecipe::Part::Order

Returns Whether the key column is sorted ascending or descending. Only present if tag is zero.

Returns:



242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
# File 'proto_docs/google/spanner/v1/location.rb', line 242

class Part
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The remaining fields encode column values.
  module Order
    # Default value, equivalent to `ASCENDING`.
    ORDER_UNSPECIFIED = 0

    # The key is ascending - corresponds to `ASC` in the schema definition.
    ASCENDING = 1

    # The key is descending - corresponds to `DESC` in the schema definition.
    DESCENDING = 2
  end

  # The null order of the key column. This dictates where NULL values sort
  # in the sorted order. Note that columns which are `NOT NULL` can have a
  # special encoding.
  module NullOrder
    # Default value. This value is unused.
    NULL_ORDER_UNSPECIFIED = 0

    # NULL values sort before any non-NULL values.
    NULLS_FIRST = 1

    # NULL values sort after any non-NULL values.
    NULLS_LAST = 2

    # The column does not support NULL values.
    NOT_NULL = 3
  end
end

#random::Boolean

Returns If true, the client is responsible to fill in the value randomly. It's relevant only for the INT64 type.

Note: The following fields are mutually exclusive: random, identifier, value. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:

  • (::Boolean)

    If true, the client is responsible to fill in the value randomly. It's relevant only for the INT64 type.

    Note: The following fields are mutually exclusive: random, identifier, value. If a field in that set is populated, all other fields in the set will automatically be cleared.



242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
# File 'proto_docs/google/spanner/v1/location.rb', line 242

class Part
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The remaining fields encode column values.
  module Order
    # Default value, equivalent to `ASCENDING`.
    ORDER_UNSPECIFIED = 0

    # The key is ascending - corresponds to `ASC` in the schema definition.
    ASCENDING = 1

    # The key is descending - corresponds to `DESC` in the schema definition.
    DESCENDING = 2
  end

  # The null order of the key column. This dictates where NULL values sort
  # in the sorted order. Note that columns which are `NOT NULL` can have a
  # special encoding.
  module NullOrder
    # Default value. This value is unused.
    NULL_ORDER_UNSPECIFIED = 0

    # NULL values sort before any non-NULL values.
    NULLS_FIRST = 1

    # NULL values sort after any non-NULL values.
    NULLS_LAST = 2

    # The column does not support NULL values.
    NOT_NULL = 3
  end
end

#struct_identifiers::Array<::Integer>

Returns It is a repeated field to support fetching key columns from nested structs, such as STRUCT query parameters.

Returns:

  • (::Array<::Integer>)

    It is a repeated field to support fetching key columns from nested structs, such as STRUCT query parameters.



242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
# File 'proto_docs/google/spanner/v1/location.rb', line 242

class Part
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The remaining fields encode column values.
  module Order
    # Default value, equivalent to `ASCENDING`.
    ORDER_UNSPECIFIED = 0

    # The key is ascending - corresponds to `ASC` in the schema definition.
    ASCENDING = 1

    # The key is descending - corresponds to `DESC` in the schema definition.
    DESCENDING = 2
  end

  # The null order of the key column. This dictates where NULL values sort
  # in the sorted order. Note that columns which are `NOT NULL` can have a
  # special encoding.
  module NullOrder
    # Default value. This value is unused.
    NULL_ORDER_UNSPECIFIED = 0

    # NULL values sort before any non-NULL values.
    NULLS_FIRST = 1

    # NULL values sort after any non-NULL values.
    NULLS_LAST = 2

    # The column does not support NULL values.
    NOT_NULL = 3
  end
end

#tag::Integer

Returns If non-zero, tag is the only field present in this Part. The part is encoded by appending tag to the ssformat key.

Returns:

  • (::Integer)

    If non-zero, tag is the only field present in this Part. The part is encoded by appending tag to the ssformat key.



242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
# File 'proto_docs/google/spanner/v1/location.rb', line 242

class Part
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The remaining fields encode column values.
  module Order
    # Default value, equivalent to `ASCENDING`.
    ORDER_UNSPECIFIED = 0

    # The key is ascending - corresponds to `ASC` in the schema definition.
    ASCENDING = 1

    # The key is descending - corresponds to `DESC` in the schema definition.
    DESCENDING = 2
  end

  # The null order of the key column. This dictates where NULL values sort
  # in the sorted order. Note that columns which are `NOT NULL` can have a
  # special encoding.
  module NullOrder
    # Default value. This value is unused.
    NULL_ORDER_UNSPECIFIED = 0

    # NULL values sort before any non-NULL values.
    NULLS_FIRST = 1

    # NULL values sort after any non-NULL values.
    NULLS_LAST = 2

    # The column does not support NULL values.
    NOT_NULL = 3
  end
end

#type::Google::Cloud::Spanner::V1::Type

Returns The type of the key part. Only present if tag is zero.

Returns:



242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
# File 'proto_docs/google/spanner/v1/location.rb', line 242

class Part
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The remaining fields encode column values.
  module Order
    # Default value, equivalent to `ASCENDING`.
    ORDER_UNSPECIFIED = 0

    # The key is ascending - corresponds to `ASC` in the schema definition.
    ASCENDING = 1

    # The key is descending - corresponds to `DESC` in the schema definition.
    DESCENDING = 2
  end

  # The null order of the key column. This dictates where NULL values sort
  # in the sorted order. Note that columns which are `NOT NULL` can have a
  # special encoding.
  module NullOrder
    # Default value. This value is unused.
    NULL_ORDER_UNSPECIFIED = 0

    # NULL values sort before any non-NULL values.
    NULLS_FIRST = 1

    # NULL values sort after any non-NULL values.
    NULLS_LAST = 2

    # The column does not support NULL values.
    NOT_NULL = 3
  end
end

#value::Google::Protobuf::Value

Returns The constant value of the key part. It is present when query uses a constant as a part of the key.

Note: The following fields are mutually exclusive: value, identifier, random. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:

  • (::Google::Protobuf::Value)

    The constant value of the key part. It is present when query uses a constant as a part of the key.

    Note: The following fields are mutually exclusive: value, identifier, random. If a field in that set is populated, all other fields in the set will automatically be cleared.



242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
# File 'proto_docs/google/spanner/v1/location.rb', line 242

class Part
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The remaining fields encode column values.
  module Order
    # Default value, equivalent to `ASCENDING`.
    ORDER_UNSPECIFIED = 0

    # The key is ascending - corresponds to `ASC` in the schema definition.
    ASCENDING = 1

    # The key is descending - corresponds to `DESC` in the schema definition.
    DESCENDING = 2
  end

  # The null order of the key column. This dictates where NULL values sort
  # in the sorted order. Note that columns which are `NOT NULL` can have a
  # special encoding.
  module NullOrder
    # Default value. This value is unused.
    NULL_ORDER_UNSPECIFIED = 0

    # NULL values sort before any non-NULL values.
    NULLS_FIRST = 1

    # NULL values sort after any non-NULL values.
    NULLS_LAST = 2

    # The column does not support NULL values.
    NOT_NULL = 3
  end
end