Class: Google::Cloud::Spanner::V1::Mutation::Ack

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/spanner/v1/mutation.rb

Overview

Arguments to ack operations.

Instance Attribute Summary collapse

Instance Attribute Details

#ignore_not_found::Boolean

Returns By default, an attempt to ack a message that does not exist will fail with a NOT_FOUND error. With ignore_not_found set to true, the ack will succeed even if the message does not exist. This is useful for unconditionally acking a message, even if it is missing or has already been acked.

Returns:

  • (::Boolean)

    By default, an attempt to ack a message that does not exist will fail with a NOT_FOUND error. With ignore_not_found set to true, the ack will succeed even if the message does not exist. This is useful for unconditionally acking a message, even if it is missing or has already been acked.



170
171
172
173
# File 'proto_docs/google/spanner/v1/mutation.rb', line 170

class Ack
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#key::Google::Protobuf::ListValue

Returns Required. The primary key of the message to be acked.

Returns:



170
171
172
173
# File 'proto_docs/google/spanner/v1/mutation.rb', line 170

class Ack
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#queue::String

Returns Required. The queue where the message to be acked is stored.

Returns:

  • (::String)

    Required. The queue where the message to be acked is stored.



170
171
172
173
# File 'proto_docs/google/spanner/v1/mutation.rb', line 170

class Ack
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end