Class: Google::Cloud::Spanner::V1::Mutation::Send

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/spanner/v1/mutation.rb

Overview

Arguments to send operations.

Instance Attribute Summary collapse

Instance Attribute Details

#deliver_time::Google::Protobuf::Timestamp

Returns The time at which Spanner will begin attempting to deliver the message. If deliver_time is not set, Spanner will deliver the message immediately. If deliver_time is in the past, Spanner will replace it with a value closer to the current time.

Returns:

  • (::Google::Protobuf::Timestamp)

    The time at which Spanner will begin attempting to deliver the message. If deliver_time is not set, Spanner will deliver the message immediately. If deliver_time is in the past, Spanner will replace it with a value closer to the current time.



151
152
153
154
# File 'proto_docs/google/spanner/v1/mutation.rb', line 151

class Send
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#key::Google::Protobuf::ListValue

Returns Required. The primary key of the message to be sent.

Returns:



151
152
153
154
# File 'proto_docs/google/spanner/v1/mutation.rb', line 151

class Send
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#payload::Google::Protobuf::Value

Returns The payload of the message.

Returns:



151
152
153
154
# File 'proto_docs/google/spanner/v1/mutation.rb', line 151

class Send
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#queue::String

Returns Required. The queue to which the message will be sent.

Returns:

  • (::String)

    Required. The queue to which the message will be sent.



151
152
153
154
# File 'proto_docs/google/spanner/v1/mutation.rb', line 151

class Send
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end