Class: Google::Cloud::Spanner::V1::PartialResultSet
- Inherits:
-
Object
- Object
- Google::Cloud::Spanner::V1::PartialResultSet
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/spanner/v1/result_set.rb
Overview
Partial results from a streaming read or SQL query. Streaming reads and SQL queries better tolerate large result sets, large rows, and large values, but are a little trickier to consume.
Instance Attribute Summary collapse
-
#cache_update ⇒ ::Google::Cloud::Spanner::V1::CacheUpdate
Optional.
-
#chunked_value ⇒ ::Boolean
If true, then the final value in values is chunked, and must be combined with more values from subsequent
PartialResultSets to obtain a complete field value. -
#last ⇒ ::Boolean
Optional.
-
#metadata ⇒ ::Google::Cloud::Spanner::V1::ResultSetMetadata
Metadata about the result set, such as row type information.
-
#precommit_token ⇒ ::Google::Cloud::Spanner::V1::MultiplexedSessionPrecommitToken
Optional.
-
#resume_token ⇒ ::String
Streaming calls might be interrupted for a variety of reasons, such as TCP connection loss.
-
#stats ⇒ ::Google::Cloud::Spanner::V1::ResultSetStats
Query plan and execution statistics for the statement that produced this streaming result set.
-
#values ⇒ ::Array<::Google::Protobuf::Value>
A streamed result set consists of a stream of values, which might be split into many
PartialResultSetmessages to accommodate large rows and/or large values.
Instance Attribute Details
#cache_update ⇒ ::Google::Cloud::Spanner::V1::CacheUpdate
Returns Optional. A cache update expresses a set of changes the client should
incorporate into its location cache. The client should discard the changes
if they are older than the data it already has. This data can be obtained
in response to requests that included a RoutingHint field, but may also
be obtained by explicit location-fetching RPCs which may be added in the
future.
192 193 194 195 |
# File 'proto_docs/google/spanner/v1/result_set.rb', line 192 class PartialResultSet include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#chunked_value ⇒ ::Boolean
Returns If true, then the final value in
values is chunked, and must be
combined with more values from subsequent PartialResultSets to obtain a
complete field value.
192 193 194 195 |
# File 'proto_docs/google/spanner/v1/result_set.rb', line 192 class PartialResultSet include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#last ⇒ ::Boolean
Returns Optional. Indicates whether this is the last PartialResultSet in the
stream. The server might optionally set this field. Clients shouldn't rely
on this field being set in all cases.
192 193 194 195 |
# File 'proto_docs/google/spanner/v1/result_set.rb', line 192 class PartialResultSet include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#metadata ⇒ ::Google::Cloud::Spanner::V1::ResultSetMetadata
Returns Metadata about the result set, such as row type information. Only present in the first response.
192 193 194 195 |
# File 'proto_docs/google/spanner/v1/result_set.rb', line 192 class PartialResultSet include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#precommit_token ⇒ ::Google::Cloud::Spanner::V1::MultiplexedSessionPrecommitToken
Returns Optional. A precommit token is included if the read-write transaction has multiplexed sessions enabled. Pass the precommit token with the highest sequence number from this transaction attempt to the Commit request for this transaction.
192 193 194 195 |
# File 'proto_docs/google/spanner/v1/result_set.rb', line 192 class PartialResultSet include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#resume_token ⇒ ::String
Returns Streaming calls might be interrupted for a variety of reasons, such
as TCP connection loss. If this occurs, the stream of results can
be resumed by re-sending the original request and including
resume_token. Note that executing any other transaction in the
same session invalidates the token.
192 193 194 195 |
# File 'proto_docs/google/spanner/v1/result_set.rb', line 192 class PartialResultSet include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#stats ⇒ ::Google::Cloud::Spanner::V1::ResultSetStats
Returns Query plan and execution statistics for the statement that produced this streaming result set. These can be requested by setting ExecuteSqlRequest.query_mode and are sent only once with the last response in the stream. This field is also present in the last response for DML statements.
192 193 194 195 |
# File 'proto_docs/google/spanner/v1/result_set.rb', line 192 class PartialResultSet include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#values ⇒ ::Array<::Google::Protobuf::Value>
Returns A streamed result set consists of a stream of values, which might
be split into many PartialResultSet messages to accommodate
large rows and/or large values. Every N complete values defines a
row, where N is equal to the number of entries in
metadata.row_type.fields.
Most values are encoded based on type as described here.
It's possible that the last value in values is "chunked",
meaning that the rest of the value is sent in subsequent
PartialResultSet(s). This is denoted by the
chunked_value field.
Two or more chunked values can be merged to form a complete value as
follows:
bool/number/null: can't be chunkedstring: concatenate the stringslist: concatenate the lists. If the last element in a list is astring,list, orobject, merge it with the first element in the next list by applying these rules recursively.object: concatenate the (field name, field value) pairs. If a field name is duplicated, then apply these rules recursively to merge the field values.
Some examples of merging:
Strings are concatenated.
"foo", "bar" => "foobar"
Lists of non-strings are concatenated.
[2, 3], [4] => [2, 3, 4]
Lists are concatenated, but the last and first elements are merged
because they are strings.
["a", "b"], ["c", "d"] => ["a", "bc", "d"]
Lists are concatenated, but the last and first elements are merged
because they are lists. Recursively, the last and first elements
of the inner lists are merged because they are strings.
["a", ["b", "c"]], [["d"], "e"] => ["a", ["b", "cd"], "e"]
Non-overlapping object fields are combined.
{"a": "1"}, {"b": "2"} => {"a": "1", "b": 2"}
Overlapping object fields are merged.
{"a": "1"}, {"a": "2"} => {"a": "12"}
Examples of merging objects containing lists of strings.
{"a": ["1"]}, {"a": ["2"]} => {"a": ["12"]}
For a more complete example, suppose a streaming SQL query is
yielding a result set whose rows contain a single string
field. The following PartialResultSets might be yielded:
{
"metadata": { ... }
"values": ["Hello", "W"]
"chunked_value": true
"resume_token": "Af65..."
}
{
"values": ["orl"]
"chunked_value": true
}
{
"values": ["d"]
"resume_token": "Zx1B..."
}
This sequence of PartialResultSets encodes two rows, one
containing the field value "Hello", and a second containing the
field value "World" = "W" + "orl" + "d".
Not all PartialResultSets contain a resume_token. Execution can only be
resumed from a previously yielded resume_token. For the above sequence of
PartialResultSets, resuming the query with "resume_token": "Af65..."
yields results from the PartialResultSet with value "orl".
192 193 194 195 |
# File 'proto_docs/google/spanner/v1/result_set.rb', line 192 class PartialResultSet include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |