Class: Google::Cloud::Spanner::V1::PartitionQueryRequest
- Inherits:
-
Object
- Object
- Google::Cloud::Spanner::V1::PartitionQueryRequest
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/spanner/v1/spanner.rb
Overview
The request for PartitionQuery
Defined Under Namespace
Classes: ParamTypesEntry
Instance Attribute Summary collapse
-
#param_types ⇒ ::Google::Protobuf::Map{::String => ::Google::Cloud::Spanner::V1::Type}
Optional.
-
#params ⇒ ::Google::Protobuf::Struct
Optional.
-
#partition_options ⇒ ::Google::Cloud::Spanner::V1::PartitionOptions
Additional options that affect how many partitions are created.
-
#session ⇒ ::String
Required.
-
#sql ⇒ ::String
Required.
-
#transaction ⇒ ::Google::Cloud::Spanner::V1::TransactionSelector
Read-only snapshot transactions are supported, read and write and single-use transactions are not.
Instance Attribute Details
#param_types ⇒ ::Google::Protobuf::Map{::String => ::Google::Cloud::Spanner::V1::Type}
Returns Optional. It isn't always possible for Cloud Spanner to infer the right SQL
type from a JSON value. For example, values of type BYTES and values of
type STRING both appear in
params as JSON strings.
In these cases, param_types can be used to specify the exact
SQL type for some or all of the SQL query parameters. See the
definition of Type for more information
about SQL types.
793 794 795 796 797 798 799 800 801 802 803 804 805 |
# File 'proto_docs/google/spanner/v1/spanner.rb', line 793 class PartitionQueryRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::Google::Cloud::Spanner::V1::Type] class ParamTypesEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#params ⇒ ::Google::Protobuf::Struct
Returns Optional. Parameter names and values that bind to placeholders in the SQL string.
A parameter placeholder consists of the @ character followed by the
parameter name (for example, @firstName). Parameter names can contain
letters, numbers, and underscores.
Parameters can appear anywhere that a literal value is expected. The same parameter name can be used more than once, for example:
"WHERE id > @msg_id AND id < @msg_id + 100"
It's an error to execute a SQL statement with unbound parameters.
793 794 795 796 797 798 799 800 801 802 803 804 805 |
# File 'proto_docs/google/spanner/v1/spanner.rb', line 793 class PartitionQueryRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::Google::Cloud::Spanner::V1::Type] class ParamTypesEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#partition_options ⇒ ::Google::Cloud::Spanner::V1::PartitionOptions
Returns Additional options that affect how many partitions are created.
793 794 795 796 797 798 799 800 801 802 803 804 805 |
# File 'proto_docs/google/spanner/v1/spanner.rb', line 793 class PartitionQueryRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::Google::Cloud::Spanner::V1::Type] class ParamTypesEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#session ⇒ ::String
Returns Required. The session used to create the partitions.
793 794 795 796 797 798 799 800 801 802 803 804 805 |
# File 'proto_docs/google/spanner/v1/spanner.rb', line 793 class PartitionQueryRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::Google::Cloud::Spanner::V1::Type] class ParamTypesEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#sql ⇒ ::String
Returns Required. The query request to generate partitions for. The request fails if the query isn't root partitionable. For a query to be root partitionable, it needs to satisfy a few conditions. For example, if the query execution plan contains a distributed union operator, then it must be the first operator in the plan. For more information about other conditions, see Read data in parallel.
The query request must not contain DML commands, such as INSERT,
UPDATE, or DELETE. Use
ExecuteStreamingSql with
a PartitionedDml transaction for large, partition-friendly DML
operations.
793 794 795 796 797 798 799 800 801 802 803 804 805 |
# File 'proto_docs/google/spanner/v1/spanner.rb', line 793 class PartitionQueryRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::Google::Cloud::Spanner::V1::Type] class ParamTypesEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#transaction ⇒ ::Google::Cloud::Spanner::V1::TransactionSelector
Returns Read-only snapshot transactions are supported, read and write and single-use transactions are not.
793 794 795 796 797 798 799 800 801 802 803 804 805 |
# File 'proto_docs/google/spanner/v1/spanner.rb', line 793 class PartitionQueryRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::Google::Cloud::Spanner::V1::Type] class ParamTypesEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |