Class: Google::Cloud::Spanner::V1::QueryAdvisorResult
- Inherits:
-
Object
- Object
- Google::Cloud::Spanner::V1::QueryAdvisorResult
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/spanner/v1/query_plan.rb
Overview
Output of query advisor analysis.
Defined Under Namespace
Classes: IndexAdvice
Instance Attribute Summary collapse
Instance Attribute Details
#index_advice ⇒ ::Array<::Google::Cloud::Spanner::V1::QueryAdvisorResult::IndexAdvice>
Returns Optional. Index Recommendation for a query. This is an optional field and the recommendation will only be available when the recommendation guarantees significant improvement in query performance.
144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 |
# File 'proto_docs/google/spanner/v1/query_plan.rb', line 144 class QueryAdvisorResult include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Recommendation to add new indexes to run queries more efficiently. # @!attribute [rw] ddl # @return [::Array<::String>] # Optional. DDL statements to add new indexes that will improve the query. # @!attribute [rw] improvement_factor # @return [::Float] # Optional. Estimated latency improvement factor. For example if the query # currently takes 500 ms to run and the estimated latency with new indexes # is 100 ms this field will be 5. class IndexAdvice include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |