Class: Google::Cloud::Spanner::V1::Range

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/spanner/v1/location.rb

Overview

A Range represents a range of keys in a database. The keys themselves are encoded in "sortable string format", also known as ssformat. Consult Spanner's open source client libraries for details on the encoding.

Each range represents a contiguous range of rows, possibly from multiple tables/indexes. Each range is associated with a single paxos group (known as a "group" throughout this API), a split (which names the exact range within the group), and a generation that can be used to determine whether a given Range represents a newer or older location for the key range.

Instance Attribute Summary collapse

Instance Attribute Details

#generation::String

Returns generation indicates the freshness of the range information contained in this proto. Generations can be compared lexicographically; if generation A is greater than generation B, then the Range corresponding to A is newer than the Range corresponding to B, and should be used preferentially.

Returns:

  • (::String)

    generation indicates the freshness of the range information contained in this proto. Generations can be compared lexicographically; if generation A is greater than generation B, then the Range corresponding to A is newer than the Range corresponding to B, and should be used preferentially.



57
58
59
60
# File 'proto_docs/google/spanner/v1/location.rb', line 57

class Range
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#group_uid::Integer

Returns The UID of the paxos group where this range is stored. UIDs are unique within the database. References Group.group_uid.

Returns:

  • (::Integer)

    The UID of the paxos group where this range is stored. UIDs are unique within the database. References Group.group_uid.



57
58
59
60
# File 'proto_docs/google/spanner/v1/location.rb', line 57

class Range
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#limit_key::String

Returns The limit key of the range, exclusive. Encoded in "sortable string format" (ssformat).

Returns:

  • (::String)

    The limit key of the range, exclusive. Encoded in "sortable string format" (ssformat).



57
58
59
60
# File 'proto_docs/google/spanner/v1/location.rb', line 57

class Range
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#split_id::Integer

Returns A group can store multiple ranges of keys. Each key range is named by an ID (the split ID). Within a group, split IDs are unique. The split_id names the exact split in group_uid where this range is stored.

Returns:

  • (::Integer)

    A group can store multiple ranges of keys. Each key range is named by an ID (the split ID). Within a group, split IDs are unique. The split_id names the exact split in group_uid where this range is stored.



57
58
59
60
# File 'proto_docs/google/spanner/v1/location.rb', line 57

class Range
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#start_key::String

Returns The start key of the range, inclusive. Encoded in "sortable string format" (ssformat).

Returns:

  • (::String)

    The start key of the range, inclusive. Encoded in "sortable string format" (ssformat).



57
58
59
60
# File 'proto_docs/google/spanner/v1/location.rb', line 57

class Range
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end