Class: Google::Cloud::Spanner::V1::RequestOptions::ClientContext

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/spanner/v1/spanner.rb

Overview

Container for various pieces of client-owned context attached to a request.

Defined Under Namespace

Classes: SecureContextEntry

Instance Attribute Summary collapse

Instance Attribute Details

#secure_context::Google::Protobuf::Map{::String => ::Google::Protobuf::Value}

Returns Optional. Map of parameter name to value for this request. These values will be returned by any SECURE_CONTEXT() calls invoked by this request (e.g., by queries against Parameterized Secure Views).

Returns:

  • (::Google::Protobuf::Map{::String => ::Google::Protobuf::Value})

    Optional. Map of parameter name to value for this request. These values will be returned by any SECURE_CONTEXT() calls invoked by this request (e.g., by queries against Parameterized Secure Views).



222
223
224
225
226
227
228
229
230
231
232
233
234
# File 'proto_docs/google/spanner/v1/spanner.rb', line 222

class ClientContext
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::Google::Protobuf::Value]
  class SecureContextEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end