Class: Google::Cloud::Spanner::V1::ResultSet

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/spanner/v1/result_set.rb

Overview

Results from Read or ExecuteSql.

Instance Attribute Summary collapse

Instance Attribute Details

#cache_update::Google::Cloud::Spanner::V1::CacheUpdate

Returns Optional. A cache update expresses a set of changes the client should incorporate into its location cache. The client should discard the changes if they are older than the data it already has. This data can be obtained in response to requests that included a RoutingHint field, but may also be obtained by explicit location-fetching RPCs which may be added in the future.

Returns:

  • (::Google::Cloud::Spanner::V1::CacheUpdate)

    Optional. A cache update expresses a set of changes the client should incorporate into its location cache. The client should discard the changes if they are older than the data it already has. This data can be obtained in response to requests that included a RoutingHint field, but may also be obtained by explicit location-fetching RPCs which may be added in the future.



61
62
63
64
# File 'proto_docs/google/spanner/v1/result_set.rb', line 61

class ResultSet
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#metadata::Google::Cloud::Spanner::V1::ResultSetMetadata

Returns Metadata about the result set, such as row type information.

Returns:



61
62
63
64
# File 'proto_docs/google/spanner/v1/result_set.rb', line 61

class ResultSet
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#precommit_token::Google::Cloud::Spanner::V1::MultiplexedSessionPrecommitToken

Returns Optional. A precommit token is included if the read-write transaction is on a multiplexed session. Pass the precommit token with the highest sequence number from this transaction attempt to the Commit request for this transaction.

Returns:



61
62
63
64
# File 'proto_docs/google/spanner/v1/result_set.rb', line 61

class ResultSet
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#rows::Array<::Google::Protobuf::ListValue>

Returns Each element in rows is a row whose format is defined by metadata.row_type. The ith element in each row matches the ith field in metadata.row_type. Elements are encoded based on type as described here.

Returns:



61
62
63
64
# File 'proto_docs/google/spanner/v1/result_set.rb', line 61

class ResultSet
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#stats::Google::Cloud::Spanner::V1::ResultSetStats

Returns Query plan and execution statistics for the SQL statement that produced this result set. These can be requested by setting ExecuteSqlRequest.query_mode. DML statements always produce stats containing the number of rows modified, unless executed using the ExecuteSqlRequest.QueryMode.PLAN ExecuteSqlRequest.query_mode. Other fields might or might not be populated, based on the ExecuteSqlRequest.query_mode.

Returns:



61
62
63
64
# File 'proto_docs/google/spanner/v1/result_set.rb', line 61

class ResultSet
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end