Class: Google::Cloud::Spanner::V1::Session

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/spanner/v1/spanner.rb

Overview

A session in the Cloud Spanner API.

Defined Under Namespace

Classes: LabelsEntry

Instance Attribute Summary collapse

Instance Attribute Details

#approximate_last_use_time::Google::Protobuf::Timestamp (readonly)

Returns Output only. The approximate timestamp when the session is last used. It's typically earlier than the actual last use time.

Returns:

  • (::Google::Protobuf::Timestamp)

    Output only. The approximate timestamp when the session is last used. It's typically earlier than the actual last use time.



102
103
104
105
106
107
108
109
110
111
112
113
114
# File 'proto_docs/google/spanner/v1/spanner.rb', line 102

class Session
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#create_time::Google::Protobuf::Timestamp (readonly)

Returns Output only. The timestamp when the session is created.

Returns:



102
103
104
105
106
107
108
109
110
111
112
113
114
# File 'proto_docs/google/spanner/v1/spanner.rb', line 102

class Session
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#creator_role::String

Returns The database role which created this session.

Returns:

  • (::String)

    The database role which created this session.



102
103
104
105
106
107
108
109
110
111
112
113
114
# File 'proto_docs/google/spanner/v1/spanner.rb', line 102

class Session
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#labels::Google::Protobuf::Map{::String => ::String}

Returns The labels for the session.

  • Label keys must be between 1 and 63 characters long and must conform to the following regular expression: [a-z]([-a-z0-9]*[a-z0-9])?.
  • Label values must be between 0 and 63 characters long and must conform to the regular expression ([a-z]([-a-z0-9]*[a-z0-9])?)?.
  • No more than 64 labels can be associated with a given session.

See https://goo.gl/xmQnxf for more information on and examples of labels.

Returns:

  • (::Google::Protobuf::Map{::String => ::String})

    The labels for the session.

    • Label keys must be between 1 and 63 characters long and must conform to the following regular expression: [a-z]([-a-z0-9]*[a-z0-9])?.
    • Label values must be between 0 and 63 characters long and must conform to the regular expression ([a-z]([-a-z0-9]*[a-z0-9])?)?.
    • No more than 64 labels can be associated with a given session.

    See https://goo.gl/xmQnxf for more information on and examples of labels.



102
103
104
105
106
107
108
109
110
111
112
113
114
# File 'proto_docs/google/spanner/v1/spanner.rb', line 102

class Session
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#multiplexed::Boolean

Returns Optional. If true, specifies a multiplexed session. Use a multiplexed session for multiple, concurrent operations including any combination of read-only and read-write transactions. Use sessions.create to create multiplexed sessions. Don't use BatchCreateSessions to create a multiplexed session. You can't delete or list multiplexed sessions.

Returns:

  • (::Boolean)

    Optional. If true, specifies a multiplexed session. Use a multiplexed session for multiple, concurrent operations including any combination of read-only and read-write transactions. Use sessions.create to create multiplexed sessions. Don't use BatchCreateSessions to create a multiplexed session. You can't delete or list multiplexed sessions.



102
103
104
105
106
107
108
109
110
111
112
113
114
# File 'proto_docs/google/spanner/v1/spanner.rb', line 102

class Session
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#name::String (readonly)

Returns Output only. The name of the session. This is always system-assigned.

Returns:

  • (::String)

    Output only. The name of the session. This is always system-assigned.



102
103
104
105
106
107
108
109
110
111
112
113
114
# File 'proto_docs/google/spanner/v1/spanner.rb', line 102

class Session
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end