Class: Google::Cloud::Spanner::V1::BatchWriteRequest
- Inherits:
-
Object
- Object
- Google::Cloud::Spanner::V1::BatchWriteRequest
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/spanner/v1/spanner.rb
Overview
The request for BatchWrite.
Defined Under Namespace
Classes: MutationGroup
Instance Attribute Summary collapse
-
#exclude_txn_from_change_streams ⇒ ::Boolean
Optional.
-
#mutation_groups ⇒ ::Array<::Google::Cloud::Spanner::V1::BatchWriteRequest::MutationGroup>
Required.
-
#request_options ⇒ ::Google::Cloud::Spanner::V1::RequestOptions
Common options for this request.
-
#session ⇒ ::String
Required.
Instance Attribute Details
#exclude_txn_from_change_streams ⇒ ::Boolean
Returns Optional. If you don't set the exclude_txn_from_change_streams option or
if it's set to false, then any change streams monitoring columns modified
by transactions will capture the updates made within that transaction.
1163 1164 1165 1166 1167 1168 1169 1170 1171 1172 1173 1174 1175 1176 1177 |
# File 'proto_docs/google/spanner/v1/spanner.rb', line 1163 class BatchWriteRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # A group of mutations to be committed together. Related mutations should be # placed in a group. For example, two mutations inserting rows with the same # primary key prefix in both parent and child tables are related. # @!attribute [rw] mutations # @return [::Array<::Google::Cloud::Spanner::V1::Mutation>] # Required. The mutations in this group. class MutationGroup include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#mutation_groups ⇒ ::Array<::Google::Cloud::Spanner::V1::BatchWriteRequest::MutationGroup>
Returns Required. The groups of mutations to be applied.
1163 1164 1165 1166 1167 1168 1169 1170 1171 1172 1173 1174 1175 1176 1177 |
# File 'proto_docs/google/spanner/v1/spanner.rb', line 1163 class BatchWriteRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # A group of mutations to be committed together. Related mutations should be # placed in a group. For example, two mutations inserting rows with the same # primary key prefix in both parent and child tables are related. # @!attribute [rw] mutations # @return [::Array<::Google::Cloud::Spanner::V1::Mutation>] # Required. The mutations in this group. class MutationGroup include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#request_options ⇒ ::Google::Cloud::Spanner::V1::RequestOptions
Returns Common options for this request.
1163 1164 1165 1166 1167 1168 1169 1170 1171 1172 1173 1174 1175 1176 1177 |
# File 'proto_docs/google/spanner/v1/spanner.rb', line 1163 class BatchWriteRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # A group of mutations to be committed together. Related mutations should be # placed in a group. For example, two mutations inserting rows with the same # primary key prefix in both parent and child tables are related. # @!attribute [rw] mutations # @return [::Array<::Google::Cloud::Spanner::V1::Mutation>] # Required. The mutations in this group. class MutationGroup include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#session ⇒ ::String
Returns Required. The session in which the batch request is to be run.
1163 1164 1165 1166 1167 1168 1169 1170 1171 1172 1173 1174 1175 1176 1177 |
# File 'proto_docs/google/spanner/v1/spanner.rb', line 1163 class BatchWriteRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # A group of mutations to be committed together. Related mutations should be # placed in a group. For example, two mutations inserting rows with the same # primary key prefix in both parent and child tables are related. # @!attribute [rw] mutations # @return [::Array<::Google::Cloud::Spanner::V1::Mutation>] # Required. The mutations in this group. class MutationGroup include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |