Class: Google::Cloud::Spanner::V1::BeginTransactionRequest
- Inherits:
-
Object
- Object
- Google::Cloud::Spanner::V1::BeginTransactionRequest
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/spanner/v1/spanner.rb
Overview
The request for BeginTransaction.
Instance Attribute Summary collapse
-
#mutation_key ⇒ ::Google::Cloud::Spanner::V1::Mutation
Optional.
-
#options ⇒ ::Google::Cloud::Spanner::V1::TransactionOptions
Required.
-
#request_options ⇒ ::Google::Cloud::Spanner::V1::RequestOptions
Common options for this request.
-
#routing_hint ⇒ ::Google::Cloud::Spanner::V1::RoutingHint
Optional.
-
#session ⇒ ::String
Required.
Instance Attribute Details
#mutation_key ⇒ ::Google::Cloud::Spanner::V1::Mutation
Returns Optional. Required for read-write transactions on a multiplexed session that commit mutations but don't perform any reads or queries. You must randomly select one of the mutations from the mutation set and send it as a part of this request.
1070 1071 1072 1073 |
# File 'proto_docs/google/spanner/v1/spanner.rb', line 1070 class BeginTransactionRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#options ⇒ ::Google::Cloud::Spanner::V1::TransactionOptions
Returns Required. Options for the new transaction.
1070 1071 1072 1073 |
# File 'proto_docs/google/spanner/v1/spanner.rb', line 1070 class BeginTransactionRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#request_options ⇒ ::Google::Cloud::Spanner::V1::RequestOptions
Returns Common options for this request.
Priority is ignored for this request. Setting the priority in this
request_options struct doesn't do anything. To set the priority for a
transaction, set it on the reads and writes that are part of this
transaction instead.
1070 1071 1072 1073 |
# File 'proto_docs/google/spanner/v1/spanner.rb', line 1070 class BeginTransactionRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#routing_hint ⇒ ::Google::Cloud::Spanner::V1::RoutingHint
Returns Optional. Makes the Spanner requests location-aware if present.
It gives the server hints that can be used to route the request to an appropriate server, potentially significantly decreasing latency and improving throughput. To achieve improved performance, most fields must be filled in with accurate values.
1070 1071 1072 1073 |
# File 'proto_docs/google/spanner/v1/spanner.rb', line 1070 class BeginTransactionRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#session ⇒ ::String
Returns Required. The session in which the transaction runs.
1070 1071 1072 1073 |
# File 'proto_docs/google/spanner/v1/spanner.rb', line 1070 class BeginTransactionRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |