Class: Google::Cloud::Spanner::V1::CacheUpdate
- Inherits:
-
Object
- Object
- Google::Cloud::Spanner::V1::CacheUpdate
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/spanner/v1/location.rb
Overview
A CacheUpdate expresses a set of changes the client should incorporate into
its location cache. These changes may or may not be newer than what the
client has in its cache, and should be discarded if necessary. CacheUpdates
can be obtained in response to requests that included a RoutingHint
field, but may also be obtained by explicit location-fetching RPCs which may
be added in the future.
Instance Attribute Summary collapse
-
#database_id ⇒ ::Integer
An internal ID for the database.
-
#group ⇒ ::Array<::Google::Cloud::Spanner::V1::Group>
A list of groups to be cached.
-
#key_recipes ⇒ ::Google::Cloud::Spanner::V1::RecipeList
A list of recipes to be cached.
-
#range ⇒ ::Array<::Google::Cloud::Spanner::V1::Range>
A list of ranges to be cached.
Instance Attribute Details
#database_id ⇒ ::Integer
Returns An internal ID for the database. Database names can be reused if a database is deleted and re-created. Each time the database is re-created, it will get a new database ID, which will never be re-used for any other database.
315 316 317 318 |
# File 'proto_docs/google/spanner/v1/location.rb', line 315 class CacheUpdate include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#group ⇒ ::Array<::Google::Cloud::Spanner::V1::Group>
Returns A list of groups to be cached.
315 316 317 318 |
# File 'proto_docs/google/spanner/v1/location.rb', line 315 class CacheUpdate include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#key_recipes ⇒ ::Google::Cloud::Spanner::V1::RecipeList
Returns A list of recipes to be cached.
315 316 317 318 |
# File 'proto_docs/google/spanner/v1/location.rb', line 315 class CacheUpdate include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#range ⇒ ::Array<::Google::Cloud::Spanner::V1::Range>
Returns A list of ranges to be cached.
315 316 317 318 |
# File 'proto_docs/google/spanner/v1/location.rb', line 315 class CacheUpdate include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |