Class: Google::Cloud::Spanner::V1::CommitResponse
- Inherits:
-
Object
- Object
- Google::Cloud::Spanner::V1::CommitResponse
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/spanner/v1/commit_response.rb
Overview
The response for Commit.
Defined Under Namespace
Classes: CommitStats
Instance Attribute Summary collapse
-
#cache_update ⇒ ::Google::Cloud::Spanner::V1::CacheUpdate
Optional.
-
#commit_stats ⇒ ::Google::Cloud::Spanner::V1::CommitResponse::CommitStats
The statistics about this
Commit. -
#commit_timestamp ⇒ ::Google::Protobuf::Timestamp
The Cloud Spanner timestamp at which the transaction committed.
-
#isolation_level ⇒ ::Google::Cloud::Spanner::V1::TransactionOptions::IsolationLevel
The isolation level used for the read-write transaction.
-
#precommit_token ⇒ ::Google::Cloud::Spanner::V1::MultiplexedSessionPrecommitToken
If specified, transaction has not committed yet.
-
#read_lock_mode ⇒ ::Google::Cloud::Spanner::V1::TransactionOptions::ReadWrite::ReadLockMode
The read lock mode used for the read-write transaction.
-
#snapshot_timestamp ⇒ ::Google::Protobuf::Timestamp
If
TransactionOptions.isolation_levelis set toIsolationLevel.REPEATABLE_READ, then the snapshot timestamp is the timestamp at which all reads in the transaction ran.
Instance Attribute Details
#cache_update ⇒ ::Google::Cloud::Spanner::V1::CacheUpdate
Returns Optional. A cache update expresses a set of changes the client should
incorporate into its location cache. The client should discard the changes
if they are older than the data it already has. This data can be obtained
in response to requests that included a RoutingHint field, but may also
be obtained by explicit location-fetching RPCs which may be added in the
future.
57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 |
# File 'proto_docs/google/spanner/v1/commit_response.rb', line 57 class CommitResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Additional statistics about a commit. # @!attribute [rw] mutation_count # @return [::Integer] # The total number of mutations for the transaction. Knowing the # `mutation_count` value can help you maximize the number of mutations # in a transaction and minimize the number of API round trips. You can # also monitor this value to prevent transactions from exceeding the system # [limit](https://cloud.google.com/spanner/quotas#limits_for_creating_reading_updating_and_deleting_data). # If the number of mutations exceeds the limit, the server returns # [INVALID_ARGUMENT](https://cloud.google.com/spanner/docs/reference/rest/v1/Code#ENUM_VALUES.INVALID_ARGUMENT). class CommitStats include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#commit_stats ⇒ ::Google::Cloud::Spanner::V1::CommitResponse::CommitStats
Returns The statistics about this Commit. Not returned by default.
For more information, see
CommitRequest.return_commit_stats.
57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 |
# File 'proto_docs/google/spanner/v1/commit_response.rb', line 57 class CommitResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Additional statistics about a commit. # @!attribute [rw] mutation_count # @return [::Integer] # The total number of mutations for the transaction. Knowing the # `mutation_count` value can help you maximize the number of mutations # in a transaction and minimize the number of API round trips. You can # also monitor this value to prevent transactions from exceeding the system # [limit](https://cloud.google.com/spanner/quotas#limits_for_creating_reading_updating_and_deleting_data). # If the number of mutations exceeds the limit, the server returns # [INVALID_ARGUMENT](https://cloud.google.com/spanner/docs/reference/rest/v1/Code#ENUM_VALUES.INVALID_ARGUMENT). class CommitStats include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#commit_timestamp ⇒ ::Google::Protobuf::Timestamp
Returns The Cloud Spanner timestamp at which the transaction committed.
57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 |
# File 'proto_docs/google/spanner/v1/commit_response.rb', line 57 class CommitResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Additional statistics about a commit. # @!attribute [rw] mutation_count # @return [::Integer] # The total number of mutations for the transaction. Knowing the # `mutation_count` value can help you maximize the number of mutations # in a transaction and minimize the number of API round trips. You can # also monitor this value to prevent transactions from exceeding the system # [limit](https://cloud.google.com/spanner/quotas#limits_for_creating_reading_updating_and_deleting_data). # If the number of mutations exceeds the limit, the server returns # [INVALID_ARGUMENT](https://cloud.google.com/spanner/docs/reference/rest/v1/Code#ENUM_VALUES.INVALID_ARGUMENT). class CommitStats include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#isolation_level ⇒ ::Google::Cloud::Spanner::V1::TransactionOptions::IsolationLevel
Returns The isolation level used for the read-write transaction.
57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 |
# File 'proto_docs/google/spanner/v1/commit_response.rb', line 57 class CommitResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Additional statistics about a commit. # @!attribute [rw] mutation_count # @return [::Integer] # The total number of mutations for the transaction. Knowing the # `mutation_count` value can help you maximize the number of mutations # in a transaction and minimize the number of API round trips. You can # also monitor this value to prevent transactions from exceeding the system # [limit](https://cloud.google.com/spanner/quotas#limits_for_creating_reading_updating_and_deleting_data). # If the number of mutations exceeds the limit, the server returns # [INVALID_ARGUMENT](https://cloud.google.com/spanner/docs/reference/rest/v1/Code#ENUM_VALUES.INVALID_ARGUMENT). class CommitStats include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#precommit_token ⇒ ::Google::Cloud::Spanner::V1::MultiplexedSessionPrecommitToken
Returns If specified, transaction has not committed yet. You must retry the commit with the new precommit token.
57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 |
# File 'proto_docs/google/spanner/v1/commit_response.rb', line 57 class CommitResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Additional statistics about a commit. # @!attribute [rw] mutation_count # @return [::Integer] # The total number of mutations for the transaction. Knowing the # `mutation_count` value can help you maximize the number of mutations # in a transaction and minimize the number of API round trips. You can # also monitor this value to prevent transactions from exceeding the system # [limit](https://cloud.google.com/spanner/quotas#limits_for_creating_reading_updating_and_deleting_data). # If the number of mutations exceeds the limit, the server returns # [INVALID_ARGUMENT](https://cloud.google.com/spanner/docs/reference/rest/v1/Code#ENUM_VALUES.INVALID_ARGUMENT). class CommitStats include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#read_lock_mode ⇒ ::Google::Cloud::Spanner::V1::TransactionOptions::ReadWrite::ReadLockMode
Returns The read lock mode used for the read-write transaction.
57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 |
# File 'proto_docs/google/spanner/v1/commit_response.rb', line 57 class CommitResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Additional statistics about a commit. # @!attribute [rw] mutation_count # @return [::Integer] # The total number of mutations for the transaction. Knowing the # `mutation_count` value can help you maximize the number of mutations # in a transaction and minimize the number of API round trips. You can # also monitor this value to prevent transactions from exceeding the system # [limit](https://cloud.google.com/spanner/quotas#limits_for_creating_reading_updating_and_deleting_data). # If the number of mutations exceeds the limit, the server returns # [INVALID_ARGUMENT](https://cloud.google.com/spanner/docs/reference/rest/v1/Code#ENUM_VALUES.INVALID_ARGUMENT). class CommitStats include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#snapshot_timestamp ⇒ ::Google::Protobuf::Timestamp
Returns If TransactionOptions.isolation_level is set to
IsolationLevel.REPEATABLE_READ, then the snapshot timestamp is the
timestamp at which all reads in the transaction ran. This timestamp is
never returned.
57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 |
# File 'proto_docs/google/spanner/v1/commit_response.rb', line 57 class CommitResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Additional statistics about a commit. # @!attribute [rw] mutation_count # @return [::Integer] # The total number of mutations for the transaction. Knowing the # `mutation_count` value can help you maximize the number of mutations # in a transaction and minimize the number of API round trips. You can # also monitor this value to prevent transactions from exceeding the system # [limit](https://cloud.google.com/spanner/quotas#limits_for_creating_reading_updating_and_deleting_data). # If the number of mutations exceeds the limit, the server returns # [INVALID_ARGUMENT](https://cloud.google.com/spanner/docs/reference/rest/v1/Code#ENUM_VALUES.INVALID_ARGUMENT). class CommitStats include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |