Class: Google::Cloud::Spanner::V1::FetchCacheUpdateRequest
- Inherits:
-
Object
- Object
- Google::Cloud::Spanner::V1::FetchCacheUpdateRequest
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/spanner/v1/spanner.rb
Overview
The request for FetchCacheUpdate.
Instance Attribute Summary collapse
-
#database ⇒ ::String
Required.
-
#max_range_count ⇒ ::Integer
Optional.
-
#max_recipe_count ⇒ ::Integer
Optional.
Instance Attribute Details
#database ⇒ ::String
Returns Required. The database for which to retrieve the cache update.
1214 1215 1216 1217 |
# File 'proto_docs/google/spanner/v1/spanner.rb', line 1214 class FetchCacheUpdateRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#max_range_count ⇒ ::Integer
Returns Optional. The maximum number of ranges to return in the response. If not set, a default limit of 10000 will be used.
1214 1215 1216 1217 |
# File 'proto_docs/google/spanner/v1/spanner.rb', line 1214 class FetchCacheUpdateRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#max_recipe_count ⇒ ::Integer
Returns Optional. The maximum number of key recipes to return in the response. If not set, a default limit of 100 will be used.
1214 1215 1216 1217 |
# File 'proto_docs/google/spanner/v1/spanner.rb', line 1214 class FetchCacheUpdateRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |