Class: Google::Cloud::Spanner::V1::Mutation::Delete
- Inherits:
-
Object
- Object
- Google::Cloud::Spanner::V1::Mutation::Delete
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/spanner/v1/mutation.rb
Overview
Arguments to delete operations.
Instance Attribute Summary collapse
-
#key_set ⇒ ::Google::Cloud::Spanner::V1::KeySet
Required.
-
#table ⇒ ::String
Required.
Instance Attribute Details
#key_set ⇒ ::Google::Cloud::Spanner::V1::KeySet
Returns Required. The primary keys of the rows within
table to delete. The primary
keys must be specified in the order in which they appear in the PRIMARY
KEY() clause of the table's equivalent DDL statement (the DDL statement
used to create the table). Delete is idempotent. The transaction will
succeed even if some or all rows do not exist.
130 131 132 133 |
# File 'proto_docs/google/spanner/v1/mutation.rb', line 130 class Delete include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |