Class: Google::Cloud::Spanner::V1::Mutation::Send
- Inherits:
-
Object
- Object
- Google::Cloud::Spanner::V1::Mutation::Send
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/spanner/v1/mutation.rb
Overview
Arguments to send operations.
Instance Attribute Summary collapse
-
#deliver_time ⇒ ::Google::Protobuf::Timestamp
The time at which Spanner will begin attempting to deliver the message.
-
#key ⇒ ::Google::Protobuf::ListValue
Required.
-
#payload ⇒ ::Google::Protobuf::Value
The payload of the message.
-
#queue ⇒ ::String
Required.
Instance Attribute Details
#deliver_time ⇒ ::Google::Protobuf::Timestamp
Returns The time at which Spanner will begin attempting to deliver the message.
If deliver_time is not set, Spanner will deliver the message
immediately. If deliver_time is in the past, Spanner will replace it
with a value closer to the current time.
151 152 153 154 |
# File 'proto_docs/google/spanner/v1/mutation.rb', line 151 class Send include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#key ⇒ ::Google::Protobuf::ListValue
Returns Required. The primary key of the message to be sent.
151 152 153 154 |
# File 'proto_docs/google/spanner/v1/mutation.rb', line 151 class Send include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |