Class: Google::Cloud::Spanner::V1::QueryAdvisorResult::IndexAdvice
- Inherits:
-
Object
- Object
- Google::Cloud::Spanner::V1::QueryAdvisorResult::IndexAdvice
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/spanner/v1/query_plan.rb
Overview
Recommendation to add new indexes to run queries more efficiently.
Instance Attribute Summary collapse
-
#ddl ⇒ ::Array<::String>
Optional.
-
#improvement_factor ⇒ ::Float
Optional.
Instance Attribute Details
#ddl ⇒ ::Array<::String>
Returns Optional. DDL statements to add new indexes that will improve the query.
157 158 159 160 |
# File 'proto_docs/google/spanner/v1/query_plan.rb', line 157 class IndexAdvice include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#improvement_factor ⇒ ::Float
Returns Optional. Estimated latency improvement factor. For example if the query currently takes 500 ms to run and the estimated latency with new indexes is 100 ms this field will be 5.
157 158 159 160 |
# File 'proto_docs/google/spanner/v1/query_plan.rb', line 157 class IndexAdvice include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |