Class: Google::Cloud::Spanner::V1::RecipeList
- Inherits:
-
Object
- Object
- Google::Cloud::Spanner::V1::RecipeList
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/spanner/v1/location.rb
Overview
A RecipeList contains a list of KeyRecipes, which share the same
schema generation.
Instance Attribute Summary collapse
-
#recipe ⇒ ::Array<::Google::Cloud::Spanner::V1::KeyRecipe>
A list of recipes to be cached.
-
#schema_generation ⇒ ::String
The schema generation of the recipes.
Instance Attribute Details
#recipe ⇒ ::Array<::Google::Cloud::Spanner::V1::KeyRecipe>
Returns A list of recipes to be cached.
290 291 292 293 |
# File 'proto_docs/google/spanner/v1/location.rb', line 290 class RecipeList include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#schema_generation ⇒ ::String
Returns The schema generation of the recipes. To be sent to the server in
RoutingHint.schema_generation whenever one of the recipes is used.
schema_generation values are comparable with each other; if generation A
compares greater than generation B, then A is a more recent schema than B.
Clients should in general aim to cache only the latest schema generation,
and discard more stale recipes.
290 291 292 293 |
# File 'proto_docs/google/spanner/v1/location.rb', line 290 class RecipeList include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |