Class: Google::Cloud::Spanner::V1::Transaction
- Inherits:
-
Object
- Object
- Google::Cloud::Spanner::V1::Transaction
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/spanner/v1/transaction.rb
Overview
A transaction.
Instance Attribute Summary collapse
-
#cache_update ⇒ ::Google::Cloud::Spanner::V1::CacheUpdate
Optional.
-
#id ⇒ ::String
idmay be used to identify the transaction in subsequent Read, ExecuteSql, Commit, or Rollback calls. -
#precommit_token ⇒ ::Google::Cloud::Spanner::V1::MultiplexedSessionPrecommitToken
A precommit token is included in the response of a BeginTransaction request if the read-write transaction is on a multiplexed session and a mutation_key was specified in the BeginTransaction.
-
#read_timestamp ⇒ ::Google::Protobuf::Timestamp
For snapshot read-only transactions, the read timestamp chosen for the transaction.
Instance Attribute Details
#cache_update ⇒ ::Google::Cloud::Spanner::V1::CacheUpdate
Returns Optional. A cache update expresses a set of changes the client should
incorporate into its location cache. The client should discard the changes
if they are older than the data it already has. This data can be obtained
in response to requests that included a RoutingHint field, but may also
be obtained by explicit location-fetching RPCs which may be added in the
future.
300 301 302 303 |
# File 'proto_docs/google/spanner/v1/transaction.rb', line 300 class Transaction include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#id ⇒ ::String
Returns id may be used to identify the transaction in subsequent
Read,
ExecuteSql,
Commit, or
Rollback calls.
Single-use read-only transactions do not have IDs, because single-use transactions do not support multiple requests.
300 301 302 303 |
# File 'proto_docs/google/spanner/v1/transaction.rb', line 300 class Transaction include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#precommit_token ⇒ ::Google::Cloud::Spanner::V1::MultiplexedSessionPrecommitToken
Returns A precommit token is included in the response of a BeginTransaction request if the read-write transaction is on a multiplexed session and a mutation_key was specified in the BeginTransaction. The precommit token with the highest sequence number from this transaction attempt should be passed to the Commit request for this transaction.
300 301 302 303 |
# File 'proto_docs/google/spanner/v1/transaction.rb', line 300 class Transaction include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#read_timestamp ⇒ ::Google::Protobuf::Timestamp
Returns For snapshot read-only transactions, the read timestamp chosen for the transaction. Not returned by default: see TransactionOptions.ReadOnly.return_read_timestamp.
A timestamp in RFC3339 UTC \"Zulu\" format, accurate to nanoseconds.
Example: "2014-10-02T15:01:23.045123456Z".
300 301 302 303 |
# File 'proto_docs/google/spanner/v1/transaction.rb', line 300 class Transaction include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |